@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: envManager.php 1318 2008-12-05 05:08:25Z fishbone $
+ * @version    SVN: $Id: envManager.php 1462 2009-01-23 08:41:29Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/version.php');	// システムバージョンクラス
@@ -46,6 +46,7 @@ class EnvManager extends Core
 	private $isMobile;			// 携帯アクセスかどうか
 	private $mobileEncoding;	// 携帯用の入力、出力エンコーディング
 	private $workDir;			// 作業用ディレクトリ
+	private $userAgent = array();	// アクセス端末の情報
 	const DEFAULT_CSV_DELIM_CODE = 'csv_delim_code';		// デフォルトのCSV区切り文字コード
 	const DEFAULT_CSV_NL_CODE = 'csv_nl_code';		// デフォルトのCSV改行コード
 	const DEFAULT_CSV_FILE_SUFFIX = 'csv_file_suffix';		// デフォルトのCSVファイル拡張子
@@ -55,14 +56,14 @@ class EnvManager extends Core
 	const DEFAULT_PAGE_ID = 'index';					// デフォルトのページID
 	const DEFAULT_MOBILE_PAGE_ID = 'm_index';					// 携帯用デフォルトのページID
 	const DEFAULT_ADMIN_PAGE_ID = 'admin_index';		// デフォルトの管理機能用ページID
+	const USER_AGENT_TYPE_PC = 'pc';					// アクセス端末の種類(PC)
+	const USER_AGENT_TYPE_MOBILE = 'mobile';			// アクセス端末の種類(携帯)
 	
 	/**
 	 * コンストラクタ
 	 */
 	function __construct()
 	{
-		//global $gInstanceManager;
-		
 		// 親クラスを呼び出す
 		parent::__construct();
 		
@@ -1173,5 +1174,123 @@ class EnvManager extends Core
 	{
 		return $this->isMobile;
 	}
+	/**
+	 * 携帯端末でのアクセスかどうか
+	 *
+	 * @return bool		true=携帯端末アクセス、false=携帯端末以外からのアクセス
+	 */
+	public function isMobileAgent()
+	{
+		global $gRequestManager;
+		
+		if (empty($this->userAgent)){
+			$agents = array(
+				// pattern: A regular-expression that matches device(browser)'s name and version
+				// profile: A group of browsers
+				// Windows CE (Microsoft(R) Internet Explorer 5.5 for Windows(R) CE)
+				// Sample: "Mozilla/4.0 (compatible; MSIE 5.5; Windows CE; sigmarion3)" (sigmarion, Hand-held PC)
+				array('pattern'=>'#\b(?:MSIE [5-9]).*\b(Windows CE)\b#',	'type'	=> self::USER_AGENT_TYPE_PC),
+
+				// ACCESS "NetFront" / "Compact NetFront" and thier OEM, expects to be "Mozilla/4.0"
+				// Sample: "Mozilla/4.0 (PS2; PlayStation BB Navigator 1.0) NetFront/3.0" (PlayStation BB Navigator, for SONY PlayStation 2)
+				// Sample: "Mozilla/4.0 (PDA; PalmOS/sony/model crdb/Revision:1.1.19) NetFront/3.0" (SONY Clie series)
+				// Sample: "Mozilla/4.0 (PDA; SL-A300/1.0,Embedix/Qtopia/1.1.0) NetFront/3.0" (SHARP Zaurus)
+				array('pattern'=>'#^(?:Mozilla/4).*\b(NetFront)/([0-9\.]+)#',	'type'	=> self::USER_AGENT_TYPE_PC),
+
+				// Embedded browsers (Non-rich)
+
+				// Windows CE (the others)
+				// Sample: "Mozilla/2.0 (compatible; MSIE 3.02; Windows CE; 240x320 )" (GFORT, NTT DoCoMo)
+				array('pattern'=>'#\b(Windows CE)\b#',	'type'	=> self::USER_AGENT_TYPE_MOBILE),
+
+				// ACCESS "NetFront" / "Compact NetFront" and thier OEM
+				// Sample: "Mozilla/3.0 (AveFront/2.6)" ("SUNTAC OnlineStation", USB-Modem for PlayStation 2)
+				// Sample: "Mozilla/3.0(DDIPOCKET;JRC/AH-J3001V,AH-J3002V/1.0/0100/c50)CNF/2.0" (DDI Pocket: AirH" Phone by JRC)
+				array('pattern'=>'#\b(NetFront)/([0-9\.]+)#',	'type'	=> self::USER_AGENT_TYPE_MOBILE),
+				array('pattern'=>'#\b(CNF)/([0-9\.]+)#',		'type'	=> self::USER_AGENT_TYPE_MOBILE),
+				array('pattern'=>'#\b(AveFront)/([0-9\.]+)#',	'type'	=> self::USER_AGENT_TYPE_MOBILE),
+				array('pattern'=>'#\b(AVE-Front)/([0-9\.]+)#',	'type'	=> self::USER_AGENT_TYPE_MOBILE), // The same?
+
+				// NTT-DoCoMo, i-mode (embeded Compact NetFront) and FOMA (embedded NetFront) phones
+				// Sample: "DoCoMo/1.0/F501i", "DoCoMo/1.0/N504i/c10/TB/serXXXX" // c以降は可変
+				// Sample: "DoCoMo/2.0 MST_v_SH2101V(c100;TB;W22H12;serXXXX;iccxxxx)" // ()の中は可変
+				array('pattern'=>'#^(DoCoMo)/([0-9\.]+)#',	'type'	=> self::USER_AGENT_TYPE_MOBILE),
+
+				// Vodafone's embedded browser
+				// Sample: "J-PHONE/2.0/J-T03"	// 2.0は"ブラウザの"バージョン
+				// Sample: "J-PHONE/4.0/J-SH51/SNxxxx SH/0001a Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.1.0"
+				array('pattern'=>'#^(J-PHONE)/([0-9\.]+)#',	'type'	=> self::USER_AGENT_TYPE_MOBILE),
+
+				// Openwave(R) Mobile Browser (EZweb, WAP phone, etc)
+				// Sample: "OPWV-SDK/62K UP.Browser/6.2.0.5.136 (GUI) MMP/2.0"
+				array('pattern'=>'#\b(UP\.Browser)/([0-9\.]+)#',	'type'	=> self::USER_AGENT_TYPE_MOBILE),
+
+				// Opera, dressing up as other embedded browsers
+				// Sample: "Mozilla/3.0(DDIPOCKET;KYOCERA/AH-K3001V/1.4.1.67.000000/0.1/C100) Opera 7.0" (Like CNF at 'keitai'-mode)
+				array('pattern'=>'#\b(?:DDIPOCKET|WILLCOM)\b.+\b(Opera) ([0-9\.]+)\b#',	'type'	=> self::USER_AGENT_TYPE_MOBILE),
+
+				// Planetweb http://www.planetweb.com/
+				// Sample: "Mozilla/3.0 (Planetweb/v1.07 Build 141; SPS JP)" ("EGBROWSER", Web browser for PlayStation 2)
+				array('pattern'=>'#\b(Planetweb)/v([0-9\.]+)#',	'type'	=> self::USER_AGENT_TYPE_MOBILE),
+
+				// DreamPassport, Web browser for SEGA DreamCast
+				// Sample: "Mozilla/3.0 (DreamPassport/3.0)"
+				array('pattern'=>'#\b(DreamPassport)/([0-9\.]+)#',	'type'	=> self::USER_AGENT_TYPE_MOBILE),
+
+				// Palm "Web Pro" http://www.palmone.com/us/support/accessories/webpro/
+				// Sample: "Mozilla/4.76 [en] (PalmOS; U; WebPro)"
+				array('pattern'=>'#\b(WebPro)\b#',	'type'	=> self::USER_AGENT_TYPE_MOBILE),
+
+				// ilinx "Palmscape" / "Xiino" http://www.ilinx.co.jp/
+				// Sample: "Xiino/2.1SJ [ja] (v. 4.1; 153x130; c16/d)"
+				array('pattern'=>'#^(Palmscape)/([0-9\.]+)#',	'type'	=> self::USER_AGENT_TYPE_MOBILE),
+				array('pattern'=>'#^(Xiino)/([0-9\.]+)#',		'type'	=> self::USER_AGENT_TYPE_MOBILE),
+
+				// SHARP PDA Browser (SHARP Zaurus)
+				// Sample: "sharp pda browser/6.1[ja](MI-E1/1.0) "
+				array('pattern'=>'#^(sharp [a-z]+ browser)/([0-9\.]+)#',	'type'	=> self::USER_AGENT_TYPE_MOBILE),
+
+				// WebTV
+				array('pattern'=>'#^(WebTV)/([0-9\.]+)#',	'type'	=> self::USER_AGENT_TYPE_MOBILE),
+
+				// Desktop-PC browsers
+
+				// Opera (for desktop PC, not embedded) -- See BugTrack/743 for detail
+				// NOTE: Keep this pattern above MSIE and Mozilla
+				// Sample: "Opera/7.0 (OS; U)" (not disguise)
+				// Sample: "Mozilla/4.0 (compatible; MSIE 5.0; OS) Opera 6.0" (disguise)
+				array('pattern'=>'#\b(Opera)[/ ]([0-9\.]+)\b#',	'type'	=> self::USER_AGENT_TYPE_PC),
+
+				// MSIE: Microsoft Internet Explorer (or something disguised as MSIE)
+				// Sample: "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0)"
+				array('pattern'=>'#\b(MSIE) ([0-9\.]+)\b#',	'type'	=> self::USER_AGENT_TYPE_PC),
+
+				// Mozilla Firefox
+				// NOTE: Keep this pattern above Mozilla
+				// Sample: "Mozilla/5.0 (Windows; U; Windows NT 5.0; ja-JP; rv:1.7) Gecko/20040803 Firefox/0.9.3"
+				array('pattern'=>'#\b(Firefox)/([0-9\.]+)\b#',	'type'	=> self::USER_AGENT_TYPE_PC),
+
+				// Loose default: Including something Mozilla
+				array('pattern'=>'#^([a-zA-z0-9 ]+)/([0-9\.]+)\b#',	'type'	=> self::USER_AGENT_TYPE_PC),
+
+				array('pattern'=>'#^#',	'type'	=> self::USER_AGENT_TYPE_PC),	// Sentinel
+			);
+
+			$userAgent = $gRequestManager->trimServerValueOf('HTTP_USER_AGENT');
+			foreach ($agents as $agent) {
+				if (preg_match($agent['pattern'], $userAgent, $matches)) {
+					$this->userAgent['type'] = isset($agent['type']) ? $agent['type'] : '';
+					$this->userAgent['name']    = isset($matches[1]) ? $matches[1] : '';	// device or browser name
+					$this->userAgent['vers']    = isset($matches[2]) ? $matches[2] : ''; // 's version
+					break;
+				}
+			}
+		}
+		if ($this->userAgent['type'] == self::USER_AGENT_TYPE_MOBILE){			// アクセス端末の種類(携帯)
+			return true;
+		} else {
+			return false;
+		}
+	}
 }
 ?>
