@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2008 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: create_base.sql 1372 2008-12-19 05:06:38Z fishbone $
+-- * @version    SVN: $Id: create_base.sql 1459 2009-01-22 10:31:03Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -585,7 +585,7 @@ CREATE TABLE _mail_send_log (
     ms_to                VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- メール送信先アドレス
     ms_from              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- メール送信元アドレス
     ms_subject           VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- メール件名
-    ms_body              VARCHAR(500)   DEFAULT ''                    NOT NULL,      -- メール本文
+    ms_body              TEXT                                         NOT NULL,      -- メール本文
     ms_dt                TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 送信日時
     PRIMARY KEY          (ms_serial)
 ) TYPE=innodb;
@@ -599,7 +599,7 @@ CREATE TABLE _mail_form (
     
     mf_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
     mf_subject           VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 件名
-    mf_content           VARCHAR(2000)  DEFAULT ''                    NOT NULL,      -- コンテンツ
+    mf_content           TEXT                                         NOT NULL,      -- コンテンツ
 
     mf_check_out_user_id INT            DEFAULT 0                     NOT NULL,      -- チェックアウトユーザID(0のときはチェックイン状態)
     mf_check_out_dt      TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- チェックアウト日時
