@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2008 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: create_std.sql 1279 2008-11-24 12:49:51Z fishbone $
+-- * @version    SVN: $Id: create_std.sql 1459 2009-01-22 10:31:03Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -316,7 +316,7 @@ CREATE TABLE bbs_thread (
     se_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
     
     se_name              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- タイトル
-    se_html              VARCHAR(2000)  DEFAULT ''                    NOT NULL,      -- 本文HTML
+    se_html              TEXT                                         NOT NULL,      -- 本文HTML
     se_status            SMALLINT       DEFAULT 0                     NOT NULL,      -- 記事状態(0=未設定、1=保留、2=表示、3=非表示)
     se_closed            BOOLEAN        DEFAULT false                 NOT NULL,      -- 投稿終了状態
     se_level             INT            DEFAULT 0                     NOT NULL,      -- 階層レベル
