@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2008 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_base.sql 1433 2009-01-13 03:54:53Z fishbone $
+-- * @version    SVN: $Id: insert_base.sql 1464 2009-01-23 08:42:04Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -22,7 +22,7 @@
 INSERT INTO _system_config 
 (sc_id,                          sc_value,                  sc_name) VALUES
 ('system_name',                 'Magic3',                   'システム名称'),
-('db_version',                  '2009010901',               'DBバージョン'),
+('db_version',                  '2009012201',               'DBバージョン'),
 ('server_id',                   '',                         'サーバ識別用ID'),
 ('default_lang',                'ja',                       'デフォルト言語'),
 ('multi_language',               '0',                       '多言語対応'),
@@ -48,7 +48,8 @@ INSERT INTO _system_config
 ('admin_default_template',      '_admin',                   '管理画面用デフォルトテンプレート'),
 ('mobile_default_template',     'm/default',                '携帯画面用デフォルトテンプレート'),
 ('msg_template',                '_admin',                   'メッセージ表示用テンプレート'),
-('head_title_format',           '$1;$1 - $2;$1 - $2 - $3;', 'HTMLヘッダタイトルフォーマット');
+('head_title_format',           '$1;$1 - $2;$1 - $2 - $3;', 'HTMLヘッダタイトルフォーマット'),
+('mobile_auto_redirect',        '0',                        '携帯アクセスの自動遷移');
 
 -- バージョン管理マスター
 INSERT INTO _version (vs_id,         vs_value,     vs_name)
