@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2007 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: access_countWidgetContainer.php 2 2007-11-03 04:59:01Z fishbone $
+ * @version    SVN: $Id: access_countWidgetContainer.php 1406 2009-01-01 08:21:17Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -18,22 +18,20 @@ require_once($gEnvManager->getCurrentWidgetDbPath()	. '/access_countDb.php');
 
 class access_countWidgetContainer extends BaseWidgetContainer
 {
-	var $db;			// DB接続オブジェクト
-    var $config = array();
+	private $db;			// DB接続オブジェクト
+    private $config = array();
 	
 	/**
 	 * コンストラクタ
 	 */
 	function __construct()
 	{
-		global $gEnvManager;
-		
 		// 親クラスを呼び出す
 		parent::__construct();
 		
 		// ###### アクセスカウンターの表示設定 ######
  		// 画像のURL
-		$this->config['img'] = $gEnvManager->getCurrentWidgetRootUrl() . '/images/';
+		$this->config['img'] = $this->gEnv->getCurrentWidgetRootUrl() . '/images/';
         $this->config['animated_img'] = $this->config['img'];
 		$this->config['animated_img_prefix'] = 'a';		// アニメーション画像ファイル用プレフィックス
 		
@@ -72,8 +70,6 @@ class access_countWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-
 		// 作成したHTMLを出力
 		$this->tmpl->addVar("_widget", "NUMBER_LIST", $this->createOutput());
 	}
