@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainOpelogWidgetContainer.php 1335 2008-12-11 03:33:38Z fishbone $
+ * @version    SVN: $Id: admin_mainOpelogWidgetContainer.php 1339 2008-12-11 09:10:23Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -237,7 +237,8 @@ class admin_mainOpelogWidgetContainer extends BaseWidgetContainer
 				$isMsgChecked = $row['ol_checked'];		// 確認済みかどうか
 				$logMsg = $row['ol_message'];		// メッセージ
 				$logMsgDetail = $row['ol_message_ext'];// メッセージ詳細
-				$accessLogSerial = $row['ol_access_log_serial'];// アクセスログシリアル番号
+				$accessLog = '';// アクセスログシリアル番号
+				if (!empty($row['ol_access_log_serial'])) $accessLog = $this->convertToDispString($row['ol_access_log_serial']);
 				$time = $this->convertToDispDateTime($row['ol_dt']);	// 出力日時
 			}
 		}
@@ -250,7 +251,7 @@ class admin_mainOpelogWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->addVar("_widget", "msg_checked", $isChecked);
 		$this->tmpl->addVar("_widget", "message", $this->convertToDispString($logMsg));
 		$this->tmpl->addVar("_widget", "detail", $this->convertToDispString($logMsgDetail));
-		$this->tmpl->addVar("_widget", "access_log_serial", $accessLogSerial);
+		$this->tmpl->addVar("_widget", "access_log_serial", $accessLog);
 		$this->tmpl->addVar("_widget", "time", $time);
 
 		// 一覧の表示条件
