@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainTemplistWidgetContainer.php 1168 2008-11-04 06:44:15Z fishbone $
+ * @version    SVN: $Id: admin_mainTemplistWidgetContainer.php 1187 2008-11-07 09:54:10Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -20,7 +20,9 @@ require_once($gEnvManager->getLibPath()				. '/pcl/pclzip.lib.php' );
 class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
+	private $sysDb;		// システムDBオブジェクト
 	private $newTemplate = array();		// 新規追加テンプレート
+	private $defalutTemplate;	// デフォルトのテンプレート
 	const TEMPLATE_THUMBNAIL_FILENAME = 'template_thumbnail.png';		// テンプレートサムネール
 	const previewImageSizeHeight = 27;
 	const previewImageSizeWidth = 42;
@@ -32,11 +34,14 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 	 */
 	function __construct()
 	{
+		global $gInstanceManager;
+				
 		// 親クラスを呼び出す
 		parent::__construct();
 		
 		// DB接続オブジェクト作成
 		$this->db = new admin_mainDb();
+		$this->sysDb = $gInstanceManager->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -69,11 +74,10 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 	{
 		global $gEnvManager;
 		global $gSystemManager;
-		
+
 		$act = $request->trimValueOf('act');
 		$selectedItemNo = $request->trimValueOf('no');		// 処理対象の項目番号
 		$userId = $gEnvManager->getCurrentUserId();
-		//$serial = $request->trimValueOf('serial');		// シリアルNo
 		$templateId = $request->trimValueOf('template');		// テンプレートID
 
 		if ($act == 'readnew'){		// テンプレート再読み込みのとき
@@ -115,37 +119,40 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 			}
 			$this->setMsg(self::MSG_GUIDANCE, $msg);
 		} else if ($act == 'updateline'){		// 行更新のとき
-			// 変更可能値
-			$updateName = $request->trimValueOf('item' . $selectedItemNo . '_name');				// 名前
-			$updateIsDefault = ($request->trimValueOf('item' . $selectedItemNo . '_isdefault') == 'on') ? 1 : 0;		// デフォルトかどうか
-			//$ret = $this->db->updateTemplate($serial, $updateName, $userId);
-			$ret = $this->db->updateTemplate($templateId, $updateName);
-			if ($ret){		// データ更新成功のとき
-				$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
-			} else {
-				$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
+			// パラメータエラーチェック
+			if (empty($templateId)) $this->setMsg(self::MSG_APP_ERR, 'テンプレートIDが指定されていません');
+			
+			if (!$this->isExistsMsg()){		// エラーなしのとき
+				// 変更可能値
+				$updateName = $request->trimValueOf('item' . $selectedItemNo . '_name');				// 名前
+				$updateIsDefault = ($request->trimValueOf('item' . $selectedItemNo . '_isdefault') == 'on') ? 1 : 0;		// デフォルトかどうか
+				$ret = $this->db->updateTemplate($templateId, $updateName);
+				if ($ret){		// データ更新成功のとき
+					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
+				} else {
+					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
+				}
 			}
 		} else if ($act == 'deleteline'){		// テンプレート削除のとき
-			//if ($this->db->getTemplate($serial, $row)){
-			// テンプレートディレクトリ取得
-			//$templateId = $row['tm_id'];
-			$templatePath = $gEnvManager->getTemplatesPath() . '/' . $templateId;
+			// パラメータエラーチェック
+			if (empty($templateId)) $this->setMsg(self::MSG_APP_ERR, 'テンプレートIDが指定されていません');
+			
+			if (!$this->isExistsMsg()){		// エラーなしのとき
+				// テンプレートディレクトリ取得
+				$templatePath = $gEnvManager->getTemplatesPath() . '/' . $templateId;
 		
-			// ディレクトリ削除
-			if ((is_dir($templatePath) && rmDirectory($templatePath)) || !is_dir($templatePath)){// 削除成功か、ディレクトリが存在しないとき
-				//$ret = $this->db->deleteTemplate($serial, $userId);
-				$ret = $this->db->deleteTemplate($templateId);
-				if ($ret){		// データ更新成功のとき
-					$this->setMsg(self::MSG_GUIDANCE, 'テンプレートを削除しました');
+				// ディレクトリ削除
+				if ((is_dir($templatePath) && rmDirectory($templatePath)) || !is_dir($templatePath)){// 削除成功か、ディレクトリが存在しないとき
+					$ret = $this->db->deleteTemplate($templateId);
+					if ($ret){		// データ更新成功のとき
+						$this->setMsg(self::MSG_GUIDANCE, 'テンプレートを削除しました');
+					} else {
+						$this->setMsg(self::MSG_APP_ERR, 'テンプレート削除に失敗しました');
+					}
 				} else {
-					$this->setMsg(self::MSG_APP_ERR, 'テンプレート削除に失敗しました');
+					$this->setMsg(self::MSG_APP_ERR, 'テンプレートのディレクトリが削除できませんでした');
 				}
-			} else {
-				$this->setMsg(self::MSG_APP_ERR, 'テンプレートのディレクトリが削除できませんでした');
 			}
-			//} else {
-			//	$this->setMsg(self::MSG_APP_ERR, '削除対象のテンプレートが見つかりません');
-			//}
 		} else if ($act == 'upload'){		// ファイルアップロードの場合
 			// アップロードされたファイルか？セキュリティチェックする
 			if (is_uploaded_file($_FILES['upfile']['tmp_name'])) {
@@ -257,11 +264,19 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 				unlink($tmpFile);
 			}
 		} else if ($act == 'changedefault'){		// デフォルトテンプレートの変更のとき
-			$this->db->changeDefaultTemplate($templateId);
+			// パラメータエラーチェック
+			if (empty($templateId)) $this->setMsg(self::MSG_APP_ERR, 'テンプレートIDが指定されていません');
+			
+			if (!$this->isExistsMsg()){		// エラーなしのとき
+				// デフォルトテンプレート変更
+				$this->db->changeDefaultTemplate($templateId);
 
-			// セッションのテンプレートIDを更新
-			$request->setSessionValue(M3_SESSION_CURRENT_TEMPLATE, $templateId);
+				// セッションのテンプレートIDを更新
+				$request->setSessionValue(M3_SESSION_CURRENT_TEMPLATE, $templateId);
+			}
 		}
+		$this->defalutTemplate = $this->sysDb->getDefaultTemplateId();// デフォルトのテンプレート
+				
 		// パラメータを設定
 		$this->tmpl->addVar("_widget", "install_dir", $gEnvManager->getTemplatesPath());// インストールディレクトリ
 		$this->tmpl->addVar("_widget", "admin_url", $gEnvManager->getDefaultAdminUrl());// 管理用URL
@@ -283,7 +298,7 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 				
 		// デフォルトテンプレート
 		$defaultButton = '';
-		if ($fetchedRow['tm_default']){
+		if ($fetchedRow['tm_id'] == $this->defalutTemplate){
 			$defaultButton = 'checked';
 		}
 		
@@ -302,10 +317,10 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 		if (!$fetchedRow['wd_editable']) $buttonEnabled = 'disabled';
 		*/
 		// 行カラーの設定
-		$lineColor = '';
+	/*	$lineColor = '';
 		if ($index % 2 != 0){
 			$lineColor = 'class="even"';		// 偶数行
-		}
+		}*/
 		// 新規に追加されたテンプレートかチェック
 		$idText = $id;
 		for ($i = 0; $i < count($this->newTemplate); $i++){
@@ -317,7 +332,7 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 		//$imageTag = '<a class="thumbnail" href="#"><img src="' . $imgUrl . '" width="' . self::previewImageSizeWidth . '" height="' . self::previewImageSizeHeight . '" border="0" /><span><img src="' . $imgUrl . '" width="' . self::imageSizeWidth . '" height="' . self::imageSizeHeight . '"/></span></a>';
 		$imageTag = '<img src="' . $imgUrl . '" width="' . self::previewImageSizeWidth . '" height="' . self::previewImageSizeHeight . '" border="0" />';
 		$row = array(
-			'line_color' => $lineColor,											// 行のカラー
+			//'line_color' => $lineColor,											// 行のカラー
 			'no' => $index + 1,													// 行番号
 			'serial' => $this->convertToDispString($fetchedRow['tm_serial']),			// シリアル番号
 			//'id_with_image' => $idSpan,			// 画像付きID
