@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainDb.php 1403 2008-12-30 14:46:51Z fishbone $
+ * @version    SVN: $Id: admin_mainDb.php 1461 2009-01-23 05:39:25Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -51,9 +51,29 @@ class admin_mainDb extends BaseDb
 	 */
 	function updateSystemConfig($key, $value)
 	{
-		$sql = "UPDATE _system_config SET sc_value = ? WHERE sc_id = ?";
-		$params = array($value, $key);
-		return $this->execStatement($sql, $params);
+		// トランザクションスタート
+		$this->startTransaction();
+		
+		$queryStr = 'SELECT sc_value FROM _system_config ';
+		$queryStr .=  'WHERE sc_id  = ?';
+		$ret = $this->selectRecord($queryStr, array($key), $row);
+		if ($ret){
+			$queryStr  = 'UPDATE _system_config ';
+			$queryStr .=   'SET sc_value = ? ';
+			$queryStr .=   'WHERE sc_id = ?';
+			$ret = $this->execStatement($queryStr, array($value, $key));			
+		} else {
+			$queryStr = 'INSERT INTO _system_config (';
+			$queryStr .=  'sc_id, ';
+			$queryStr .=  'sc_value ';
+			$queryStr .=  ') VALUES (';
+			$queryStr .=  '?, ?';
+			$queryStr .=  ')';
+			$ret = $this->execStatement($queryStr, array($key, $value));	
+		}
+		// トランザクション終了
+		$ret = $this->endTransaction();
+		return $ret;
 	}
 	/**
 	 * サイト定義値を更新
