@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_calendar_boxWidgetContainer.php 2 2007-11-03 04:59:01Z fishbone $
+ * @version    SVN: $Id: blog_calendar_boxWidgetContainer.php 1450 2009-01-16 09:18:25Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -20,8 +20,8 @@ require_once($gEnvManager->getLibPath()			. '/Calendar-0.5.3/Month/Weekdays.php'
 class blog_calendar_boxWidgetContainer extends BaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $sysDb;		// システムDBオブジェクト
 	private $entryDays = array();		// 投稿のあった日にち
+	private $css;	// カレンダー用CSS
 	const TARGET_WIDGET = 'blog_main';		// 呼び出しウィジェットID
 	const THIS_WIDGET_ID = 'blog_calendar_box';		// ウィジェットID
 		
@@ -30,14 +30,11 @@ class blog_calendar_boxWidgetContainer extends BaseWidgetContainer
 	 */
 	function __construct()
 	{
-		global $gInstanceManager;
-			
 		// 親クラスを呼び出す
 		parent::__construct();
 		
 		// DB接続オブジェクト作成
 		$this->db = new blog_calendar_boxDb();
-		$this->sysDb = $gInstanceManager->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -64,10 +61,7 @@ class blog_calendar_boxWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		global $gPageManager;
-		global $gDesignManager;
-
+		$now = date("Y/m/d H:i:s");	// 現在日時
 		$year = $request->trimValueOf('year');		// 年指定
 		if (!(is_numeric($year) && 1 <= $year)){			// エラー値のとき
 			$year = date('Y');
@@ -79,10 +73,7 @@ class blog_calendar_boxWidgetContainer extends BaseWidgetContainer
 		$day = $request->trimValueOf('day');		// 日指定
 		
 		// メニューテーブルのパラメータ
-		$this->tmpl->addVar("_widget", "default_menu_param", $gDesignManager->getDefaultWidgetTableParam());
-		
-		// 画像URL
-		$this->tmpl->addVar("_widget", "IMG_URL", $gEnvManager->getCurrentWidgetRootUrl() . '/images');
+		$this->tmpl->addVar("_widget", "default_menu_param", $this->gDesign->getDefaultWidgetTableParam());
 		
 		// カレンダーを作成
 		$calendar = new Calendar_Month_Weekdays($year, $month, 0);		// 日曜日を先頭にする
@@ -102,17 +93,17 @@ class blog_calendar_boxWidgetContainer extends BaseWidgetContainer
 		// データの存在する日を取得
 		$startDt = $this->convertToProperDate($year . '/' . $month . '/1');
 		$endDt = $this->convertToProperDate($nextYear . '/' . $nextMonth . '/1');
-		$this->db->getEntryItems($startDt, $endDt, $gEnvManager->getCurrentLanguage(), array($this, 'itemLoop'));
+		$this->db->getEntryItems($now, $startDt, $endDt, $this->gEnv->getCurrentLanguage(), array($this, 'itemLoop'));
 		
-		$prevUrl = $gPageManager->createWidgetCmdUrl('', self::TARGET_WIDGET, self::THIS_WIDGET_ID, 'act=view&year=' . $prevYear . '&month=' . $prevMonth);
-		$nextUrl = $gPageManager->createWidgetCmdUrl('', self::TARGET_WIDGET, self::THIS_WIDGET_ID, 'act=view&year=' . $nextYear . '&month=' . $nextMonth);
+		$prevUrl = $this->gPage->createWidgetCmdUrl('', self::TARGET_WIDGET, self::THIS_WIDGET_ID, 'act=view&year=' . $prevYear . '&month=' . $prevMonth);
+		$nextUrl = $this->gPage->createWidgetCmdUrl('', self::TARGET_WIDGET, self::THIS_WIDGET_ID, 'act=view&year=' . $nextYear . '&month=' . $nextMonth);
 		$calendarData = '';
 		$calendarData .= '<table class="blog_calendar">' . M3_NL;
 //		$calendarData .= '<caption>' . M3_NL;
 		$calendarData .= '<div align="center">' . M3_NL;
-		$calendarData .= '<a href="' . $prevUrl . '">' . $prevMonth. '</a>' . M3_NL;
+		$calendarData .= '<a href="' . $this->convertUrlToHtmlEntity($prevUrl) . '">' . $prevMonth. '</a>' . M3_NL;
 		$calendarData .= ' | ' . $year . '/' . $month . ' | ' . M3_NL;
-		$calendarData .= '<a href="' . $nextUrl . '">' . $nextMonth . '</a>' . M3_NL;
+		$calendarData .= '<a href="' . $this->convertUrlToHtmlEntity($nextUrl) . '">' . $nextMonth . '</a>' . M3_NL;
 //		$calendarData .= '</caption>' . M3_NL;
 		$calendarData .= '</div>' . M3_NL;
 		$calendarData .= '<tr>' . M3_NL;
@@ -133,8 +124,8 @@ class blog_calendar_boxWidgetContainer extends BaseWidgetContainer
 		        $calendarData .= "<td>&nbsp;</td>\n";
 		    } else {
 				if (in_array($Day->thisDay(), $this->entryDays)){			// 投稿記事あり
-					$dayUrl = $gPageManager->createWidgetCmdUrl('', self::TARGET_WIDGET, self::THIS_WIDGET_ID, 'act=view&year=' . $year . '&month=' . $month . '&day=' . $Day->thisDay());
-					$dayLink = '<a href="' . $dayUrl . '">' . $Day->thisDay(). '</a>';
+					$dayUrl = $this->gPage->createWidgetCmdUrl('', self::TARGET_WIDGET, self::THIS_WIDGET_ID, 'act=view&year=' . $year . '&month=' . $month . '&day=' . $Day->thisDay());
+					$dayLink = '<a href="' . $this->convertUrlToHtmlEntity($dayUrl) . '">' . $Day->thisDay(). '</a>';
 					$calendarData .= '<td>'. $dayLink ."</td>\n";
 				} else {
 		        	$calendarData .= '<td>'.$Day->thisDay()."</td>\n";
@@ -147,6 +138,23 @@ class blog_calendar_boxWidgetContainer extends BaseWidgetContainer
 		}
 		$calendarData .= "</table></div>\n";
 		$this->tmpl->addVar("_widget", "calendar", $calendarData);
+		
+		// CSSを作成
+		$this->css = $this->getParsedTemplateData('default.tmpl.css', array($this, 'makeCss'));
+	}
+	/**
+	 * CSSデータをHTMLヘッダ部に設定
+	 *
+	 * CSSデータをHTMLのheadタグ内に追加出力する。
+	 * _assign()よりも後に実行される。
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param object         $param			任意使用パラメータ。
+	 * @return string 						CSS文字列。出力しない場合は空文字列を設定。
+	 */
+	function _addCssData($request, &$param)
+	{
+		return $this->css;
 	}
 	/**
 	 * 取得したデータをテンプレートに設定する
@@ -158,13 +166,22 @@ class blog_calendar_boxWidgetContainer extends BaseWidgetContainer
 	 */
 	function itemLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		// 日を取得
 		$this->timestampToYearMonthDay($fetchedRow['be_regist_dt'], $year, $month, $day);
 		
 		if (!in_array($day, $this->entryDays)) $this->entryDays[] = $day;
 		return true;
 	}
+	/**
+	 * CSSデータ作成処理コールバック
+	 *
+	 * @param object         $tmpl			テンプレートオブジェクト
+	 * @param								なし
+	 */
+	function makeCss($tmpl)
+	{
+		// 画像URL
+		$tmpl->addVar("_tmpl", "IMG_URL", $this->gEnv->getCurrentWidgetRootUrl() . '/images');
+	}
 }
 ?>
