@@ -1,6 +1,6 @@
 <?php
 // PukiWiki - Yet another WikiWikiWeb clone.
-// $Id: default.ini.php 1111 2008-10-24 01:25:15Z fishbone $
+// $Id: default.ini.php 1173 2008-11-05 01:01:47Z fishbone $
 // Copyright (C)
 //   2003-2005 PukiWiki Developers Team
 //   2001-2002 Originally written by yu-ji
@@ -63,7 +63,8 @@ $_ol_margin = 16;       // リストの階層間の間隔(px)
 $_dl_left_margin = 0;   // リストと画面左端との間隔(px)
 $_dl_margin = 16;        // リストの階層間の間隔(px)
 //$_list_pad_str = ' class="list%d" style="padding-left:%dpx;margin-left:%dpx"';
-$_list_pad_str = ' class="list%d"';
+//$_list_pad_str = ' class="list%d"';
+$_list_pad_str = ' class="wiki_list%d"';			// リストクラス名
 
 /////////////////////////////////////////////////
 // テキストエリアのカラム数
