@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: backup.inc.php 1124 2008-10-25 04:09:51Z fishbone $
+ * @version    SVN: $Id: backup.inc.php 1141 2008-10-27 06:10:58Z fishbone $
  * @link       http://www.magic3.org
  */
 // Copyright (C)
@@ -86,21 +86,20 @@ function plugin_backup_action()
 			$_msg_view) . '</li>' . "\n";
 
 	if ($is_page) {
-		$body .= ' <li>' . str_replace('$1',
-			'<a href="' . $script . '?' . $r_page . '">' . $s_page . '</a>',
-			$_msg_goto) . "\n";
+		//$body .= ' <li>' . str_replace('$1', '<a href="' . $script . '?' . $r_page . '">' . $s_page . '</a>', $_msg_goto) . "\n";
+		$body .= ' <li>' . str_replace('$1', '<a href="' . $script . WikiParam::convQuery('?' . $r_page) . '">' . $s_page . '</a>', $_msg_goto) . "\n";
 	} else {
 		$body .= ' <li>' . str_replace('$1', $s_page, $_msg_deleted) . "\n";
 	}
 
 	//$backups = get_backup($page);
 	$backups = WikiPage::getPageBackupInfo($page);
-	
 	$backups_count = count($backups);
 	if ($s_age > $backups_count) $s_age = $backups_count;
 
 	if ($backups_count > 0) {
-		$body .= '  <ul>' . "\n";
+		//$body .= '  <ul>' . "\n";
+		$body .= '  <ul class="wiki_list">' . "\n";
 		foreach($backups as $age => $val) {
 			$date = format_date($val['time'], TRUE);
 			/*$body .= ($age == $s_age) ?
@@ -151,8 +150,8 @@ function plugin_backup_delete($page)
 	global $_title_backup_delete, $_title_pagebackuplist, $_msg_backup_deleted;
 	global $_msg_backup_adminpass, $_btn_delete, $_msg_invalidpass;
 
-	if (! _backup_file_exists($page))
-		return array('msg'=>$_title_pagebackuplist, 'body'=>plugin_backup_get_list($page)); // Say "is not found"
+	//if (! _backup_file_exists($page))
+	if (!WikiPage::isPageBackup($page)) return array('msg'=>$_title_pagebackuplist, 'body'=>plugin_backup_get_list($page)); // Say "is not found"
 
 	$body = '';
 	$pass = WikiParam::getVar('pass');
@@ -248,7 +247,7 @@ EOD;
 </ul>
 EOD;*/
 	$retval[0] = <<<EOD
-<ul>
+<ul class="wiki_list">
  <li><a href="$postScript">$_msg_backuplist</a>
   <ul>
 EOD;
@@ -311,7 +310,8 @@ function plugin_backup_get_list_all($withfilename = FALSE)
 {
 	global $cantedit;
 
-	$pages = array_diff(get_existpages(BACKUP_DIR, BACKUP_EXT), $cantedit);
+	//$pages = array_diff(get_existpages(BACKUP_DIR, BACKUP_EXT), $cantedit);
+	$pages = array_diff(WikiPage::getAllBackupPages(), $cantedit);
 
 	if (empty($pages)) {
 		return '';
